==> igniteui-webcomponents-layouts-4.3.2.tgz: package/esm2015/lib/igc-tool-action-icon-button-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionIconButton } from "./ToolActionIconButton";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionIconButtonComponent = /*@__PURE__*/ (() => {
    class IgcToolActionIconButtonComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionIconButton();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent == null) {
                let names = getAllPropertyNames(IgcToolActionIconButtonComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = names;
            }
            return IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent;
        }
        static register() {
            if (!IgcToolActionIconButtonComponent._isElementRegistered) {
                IgcToolActionIconButtonComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionIconButtonComponent.htmlTagName, IgcToolActionIconButtonComponent);
            }
        }
        /**
         * Gets or sets how long it takes before the tooltip is displayed (in milliseconds).
        */
        get tooltipDelay() {
            return this.i.fk;
        }
        set tooltipDelay(v) {
            this.i.fk = +v;
            this._a("tooltipDelay", this.i.fk);
        }
        cleanUp() {
            this.i.dd();
        }
        openSubMenu() {
            this.i.d2();
        }
        closeSubmenu() {
            this.i.df();
        }
        fromInfo(info) {
            this.i.dp(info);
        }
    }
    IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = null;
    IgcToolActionIconButtonComponent.htmlTagName = "igc-tool-action-icon-button";
    IgcToolActionIconButtonComponent._isElementRegistered = false;
    return IgcToolActionIconButtonComponent;
})();

==> igniteui-webcomponents-layouts-4.8.0.tgz: package/esm2015/lib/igc-tool-action-icon-button-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionIconButton } from "./ToolActionIconButton";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionIconButtonComponent = /*@__PURE__*/ (() => {
    class IgcToolActionIconButtonComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionIconButton();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent == null) {
                let names = getAllPropertyNames(IgcToolActionIconButtonComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = names;
            }
            return IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent;
        }
        static register() {
            if (!IgcToolActionIconButtonComponent._isElementRegistered) {
                IgcToolActionIconButtonComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionIconButtonComponent.htmlTagName, IgcToolActionIconButtonComponent);
            }
        }
        /**
         * Gets or sets how long it takes before the tooltip is displayed (in milliseconds).
        */
        get tooltipDelay() {
            return this.i.fo;
        }
        set tooltipDelay(v) {
            this.i.fo = +v;
            this._a("tooltipDelay", this.i.fo);
        }
        cleanUp() {
            this.i.dh();
        }
        openSubMenu() {
            this.i.d6();
        }
        closeSubmenu() {
            this.i.dj();
        }
        fromInfo(info) {
            this.i.dt(info);
        }
    }
    IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = null;
    IgcToolActionIconButtonComponent.htmlTagName = "igc-tool-action-icon-button";
    IgcToolActionIconButtonComponent._isElementRegistered = false;
    return IgcToolActionIconButtonComponent;
})();
